@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Выдаліць абраны адрас са спісу</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Увядзіце адрас ці пазнаку для пошуку</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Экспартаваць гэтыя звесткі у файл</translation>
@@ -601,10 +605,6 @@
         <source>&amp;Address</source>
         <translation>Адрас</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Новы адрас для атрымання</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Новы адрас для дасылання</translation>
@@ -617,10 +617,6 @@
         <source>Edit sending address</source>
         <translation>Рэдагаваць адрас дасылання</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Уведзены адрас "%1" ужо ў кніге адрасоў</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Немагчыма разблакаваць гаманец</translation>
@@ -655,19 +651,7 @@
         <source>Command-line options</source>
         <translation>Опцыі каманднага радка</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Ужыванне:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>опцыі каманднага радка</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>Стартаваць ммінімізаванай</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -802,6 +786,10 @@
         <source>Message</source>
         <translation>Паведамленне</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Гаманец</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -985,10 +973,6 @@
 </context>
 <context>
     <name>TransactionDesc</name>
-    <message>
-        <source>%1/offline</source>
-        <translation>%1/offline</translation>
-    </message>
     <message>
         <source>%1/unconfirmed</source>
         <translation>%1/непацверджана</translation>
@@ -1001,10 +985,6 @@
         <source>Status</source>
         <translation>Статус</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, пакуль не было паспяхова транслявана</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Дата</translation>
@@ -1055,10 +1035,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>Пацверджана (%1 пацверджанняў)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Гэты блок не быў прыняты іншымі вузламі і магчыма не будзе ўхвалены!</translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>Згенеравана, але не прынята</translation>
@@ -1249,22 +1225,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Опцыі:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Вызначыць каталог даных</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>Прымаць камандны радок і JSON-RPC каманды</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>Запусціць у фоне як дэман і прымаць каманды</translation>
-    </message>
     <message>
         <source>Bitcoin Core</source>
         <translation>Bitcoin Core</translation>
@@ -1301,30 +1261,14 @@
         <source>Not enough file descriptors available.</source>
         <translation>Не хапае файлавых дэскрыптараў.</translation>
     </message>
-    <message>
-        <source>Use UPnP to map the listening port (default: %u)</source>
-        <translation>Use UPnP to map the listening port (default: %u)</translation>
-    </message>
     <message>
         <source>Verifying blocks...</source>
         <translation>Праверка блокаў...</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>Опцыі гаманца:</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Інфармацыя</translation>
     </message>
-    <message>
-        <source>RPC server options:</source>
-        <translation>Опцыі RPC сервера:</translation>
-    </message>
-    <message>
-        <source>Send trace/debug info to console instead of debug.log file</source>
-        <translation>Слаць trace/debug звесткі ў кансоль замест файла debug.log</translation>
-    </message>
     <message>
         <source>Signing transaction failed</source>
         <translation>Памылка подпісу транзакцыі</translation>
@@ -1341,22 +1285,10 @@
         <source>Transaction too large</source>
         <translation>Транзакцыя занадта вялікая</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>Імя карыстальника для JSON-RPC злучэнняў</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Увага</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>Пароль для JSON-RPC злучэнняў</translation>
-    </message>
-    <message>
-        <source>Execute command when the best block changes (%s in cmd is replaced by block hash)</source>
-        <translation>Выканаць каманду калі лепшы блок зменіцца (%s замяняецца на хэш блока)</translation>
-    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Недастаткова сродкаў</translation>
