@@ -441,10 +441,6 @@
         <source>Edit Address</source>
         <translation>Редактирайте адреса</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Нов адрес за получаване</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Нов адрес за изпращане</translation>
@@ -678,6 +674,10 @@
         <source>Label</source>
         <translation>Етикет</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>портфейл</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
