@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Eliminar la dirección seleccionada de la lista</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Ingresar la dirección o etiqueta para buscar</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Exportar los datos en la pestaña actual a un archivo</translation>
@@ -335,6 +339,10 @@
         <source>Copy &amp;Address</source>
         <translation>Copiar Dirección</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Billetera</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -466,10 +474,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opciones:</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Información</translation>
