@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Ezabatu aukeratutako helbideak listatik</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Bilatzeko, helbide edo etiketa sartu</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Uneko fitxategian datuak esportatu</translation>
@@ -335,10 +339,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Helbidea</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Jasotzeko helbide berria</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Bidaltzeko helbide berria</translation>
@@ -351,10 +351,6 @@
         <source>Edit sending address</source>
         <translation>Bidaltzeko helbidea editatu</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Sartu berri den helbidea, "%1", helbide-liburuan dago jadanik.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Ezin da diruzorroa desblokeatu.</translation>
@@ -603,10 +599,6 @@
         <source>%1 confirmations</source>
         <translation>%1 konfirmazio</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, ez da oraindik arrakastaz igorri</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Data</translation>
@@ -657,10 +649,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>Konfirmatuta (%1 konfirmazio)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Bloke hau ez du beste inongo nodok jaso, eta seguruenik ez da onartuko!</translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>Sortua, baina ez onartua</translation>
@@ -819,10 +807,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Aukerak:</translation>
-    </message>
     <message>
         <source>Rescanning...</source>
         <translation>Birbilatzen...</translation>
