@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>حذف آدرس های انتخاب شده از لیست</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>آدرس یا برچسب را برای جستجو وارد کنید</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>صدور داده نوار جاری به یک فایل</translation>
@@ -131,6 +135,10 @@
         <source>Repeat new passphrase</source>
         <translation>رمز/پَس فرِیز را دوباره وارد کنید</translation>
     </message>
+    <message>
+        <source>Show password</source>
+        <translation>نمایش گذرواژه</translation>
+    </message>
     <message>
         <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
         <translation>رمز جدید را در کیف‌پول وارد کنید. &lt;br/&gt;لطفا از رمزی استفاده کنید که&lt;b&gt; حداقل ۱۰ کاراکتر راندوم&lt;/b&gt;یا&lt;b&gt;حداقل ۸ کلمه داشته باشد&lt;/b&gt;.</translation>
@@ -241,6 +249,10 @@
         <source>&amp;Overview</source>
         <translation>بازبینی</translation>
     </message>
+    <message>
+        <source>Node</source>
+        <translation>گره</translation>
+    </message>
     <message>
         <source>Show general overview of wallet</source>
         <translation>نمای کلی از wallet را نشان بده</translation>
@@ -305,6 +317,14 @@
         <source>&amp;Receiving addresses...</source>
         <translation>دریافت آدرس ها</translation>
     </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>کیف پول:</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>کیف پول پیش‌فرض</translation>
+    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>برای غیرفعال‌کردن فعالیت شبکه کلیک کنید.</translation>
@@ -357,6 +377,10 @@
         <source>&amp;Send</source>
         <translation>ارسال</translation>
     </message>
+    <message>
+        <source>&amp;Receive</source>
+        <translation>دریافت</translation>
+    </message>
     <message>
         <source>&amp;Show / Hide</source>
         <translation>نمایش/ عدم نمایش</translation>
@@ -425,10 +449,26 @@
         <source>Processed %n block(s) of transaction history.</source>
         <translation><numerusform>%n بلاک از تاریخچه تراکنش، پردازش شد.</numerusform><numerusform>%n بلاک از تاریخچه تراکنش، پردازش شد.</numerusform></translation>
     </message>
+    <message>
+        <source>%1 behind</source>
+        <translation>%1 قبل</translation>
+    </message>
+    <message>
+        <source>Transactions after this will not yet be visible.</source>
+        <translation>تراکنش‌های بعد از این تراکنش هنوز در دسترس نیستند.</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>خطا</translation>
     </message>
+    <message>
+        <source>Warning</source>
+        <translation>هشدار</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>اطلاعات</translation>
+    </message>
     <message>
         <source>Up to date</source>
         <translation>به روز</translation>
@@ -437,6 +477,18 @@
         <source>Catching up...</source>
         <translation>در حال روزآمد سازی..</translation>
     </message>
+    <message>
+        <source>Amount: %1
+</source>
+        <translation>مبلغ: %1
+</translation>
+    </message>
+    <message>
+        <source>Address: %1
+</source>
+        <translation>آدرس: %1
+</translation>
+    </message>
     <message>
         <source>Sent transaction</source>
         <translation>تراکنش ارسالی</translation>
@@ -480,6 +532,14 @@
         <source>(un)select all</source>
         <translation>(عدم)انتخاب همه</translation>
     </message>
+    <message>
+        <source>Tree mode</source>
+        <translation>حالت درختی</translation>
+    </message>
+    <message>
+        <source>List mode</source>
+        <translation>حالت لیستی</translation>
+    </message>
     <message>
         <source>Amount</source>
         <translation>میزان</translation>
@@ -555,10 +615,6 @@
         <source>&amp;Address</source>
         <translation>آدرس</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>آدرس دریافتی جدید</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>آدرس ارسالی جدید</translation>
@@ -571,6 +627,10 @@
         <source>Edit sending address</source>
         <translation>ویرایش آدرس ارسالی</translation>
     </message>
+    <message>
+        <source>The entered address "%1" is not a valid Bitcoin address.</source>
+        <translation>آدرس وارد شده "%1" آدرس معتبر بیت کوین نیست.</translation>
+    </message>
     </context>
 <context>
     <name>FreespaceChecker</name>
@@ -585,10 +645,6 @@
         <source>version</source>
         <translation>نسخه</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>میزان استفاده:</translation>
-    </message>
     </context>
 <context>
     <name>Intro</name>
@@ -596,10 +652,18 @@
         <source>Welcome</source>
         <translation>خوش آمدید</translation>
     </message>
+    <message>
+        <source>Welcome to %1.</source>
+        <translation>به %1 خوش آمدید.</translation>
+    </message>
     <message>
         <source>Bitcoin</source>
         <translation>بیت کوین</translation>
     </message>
+    <message>
+        <source>The wallet will also be stored in this directory.</source>
+        <translation>کیف پول هم در همین دایرکتوری ذخیره می‌شود.</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>خطا</translation>
@@ -611,10 +675,22 @@
         <source>Form</source>
         <translation>فرم</translation>
     </message>
+    <message>
+        <source>Number of blocks left</source>
+        <translation>تعداد بلوک‌های باقیمانده</translation>
+    </message>
     <message>
         <source>Unknown...</source>
         <translation>ناشناس...</translation>
     </message>
+    <message>
+        <source>Last block time</source>
+        <translation>زمان آخرین بلوک</translation>
+    </message>
+    <message>
+        <source>Progress</source>
+        <translation>پیشرفت</translation>
+    </message>
     <message>
         <source>calculating...</source>
         <translation>در حال محاسبه...</translation>
@@ -754,6 +830,14 @@
         <source>Current number of blocks</source>
         <translation>تعداد زنجیره های حاضر</translation>
     </message>
+    <message>
+        <source>Last block time</source>
+        <translation>زمان آخرین بلوک</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>کیف پول پیش‌فرض</translation>
+    </message>
     </context>
 <context>
     <name>ReceiveCoinsDialog</name>
@@ -796,6 +880,10 @@
         <source>Label</source>
         <translation>برچسب</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>کیف پول</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1079,57 +1167,17 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>انتخابها:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>دایرکتوری داده را مشخص کن</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>command line  و JSON-RPC commands را قبول کنید</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>به عنوان daemon بک گراند را اجرا کنید و دستورات را قبول نمایید</translation>
-    </message>
     <message>
         <source>The transaction amount is too small to send after the fee has been deducted</source>
         <translation>مبلغ تراکنش کمتر از آن است که پس از کسر هزینه  تراکنش قابل ارسال باشد</translation>
     </message>
     <message>
-        <source>RPC server options:</source>
-        <translation>گزینه های سرویس دهنده RPC:</translation>
+        <source>Information</source>
+        <translation>اطلاعات</translation>
     </message>
     <message>
-        <source>Send trace/debug info to console instead of debug.log file</source>
-        <translation>ارسال اطلاعات پیگیری/خطایابی به کنسول به جای ارسال به فایل debug.log</translation>
-    </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>شناسه کاربری برای ارتباطاتِ JSON-RPC</translation>
-    </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>رمز برای ارتباطاتِ JSON-RPC</translation>
-    </message>
-    <message>
-        <source>Execute command when the best block changes (%s in cmd is replaced by block hash)</source>
-        <translation>دستور را وقتی بهترین بلاک تغییر کرد اجرا کن (%s در دستور توسط block hash جایگزین شده است)</translation>
-    </message>
-    <message>
-        <source>Set the number of threads to service RPC calls (default: %d)</source>
-        <translation>تنظیم تعداد ریسمان ها برای سرویس دهی فراخوانی های RPC (پیش فرض: %d)</translation>
-    </message>
-    <message>
-        <source>Specify configuration file (default: %s)</source>
-        <translation>فایل تنظیمات را مشخص کنید (پیش فرض: %s)</translation>
-    </message>
-    <message>
-        <source>Specify pid file (default: %s)</source>
-        <translation>فایل pid را مشخص کنید (پیش فرض: %s)</translation>
+        <source>Warning</source>
+        <translation>هشدار</translation>
     </message>
     <message>
         <source>Insufficient funds</source>
