@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Brisanje trenutno odabrane adrese s popisa.</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Unesite adresu ili oznaku za pretraživanje</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Izvoz podataka iz trenutnog lista u datoteku</translation>
@@ -601,10 +605,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Adresa</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Nova adresa za primanje</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Nova adresa za slanje</translation>
@@ -621,10 +621,6 @@
         <source>The entered address "%1" is not a valid Bitcoin address.</source>
         <translation>Upisana adresa "%1" nije valjana bitcoin adresa.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Upisana adresa "%1" je već u adresaru.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Ne mogu otključati novčanik.</translation>
@@ -663,19 +659,7 @@
         <source>Command-line options</source>
         <translation>Opcije programa u naredbenoj liniji</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Upotreba:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>opcije programa u naredbenoj liniji</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>Pokreni minimiziran</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -1074,6 +1058,10 @@
         <source>Message</source>
         <translation>Poruka</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Novčanik</translation>
+    </message>
     <message>
         <source>Resulting URI too long, try to reduce the text for label / message.</source>
         <translation>URI je predug, probajte skratiti tekst za naslov / poruku.</translation>
@@ -1180,6 +1168,10 @@
         <source>or</source>
         <translation>ili</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Naknada za transakciju</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Potvrdi slanje novca</translation>
@@ -1313,10 +1305,6 @@
         <source>Open until %1</source>
         <translation>Otvoren do %1</translation>
     </message>
-    <message>
-        <source>%1/offline</source>
-        <translation>%1 nije dostupan</translation>
-    </message>
     <message>
         <source>%1/unconfirmed</source>
         <translation>%1/nepotvrđeno</translation>
@@ -1329,10 +1317,6 @@
         <source>Status</source>
         <translation>Status</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, još nije bio uspješno emitiran</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Datum</translation>
@@ -1439,10 +1423,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>Potvrđen (%1 potvrda)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Ovaj blok nije bio primljen od strane bilo kojeg drugog čvora i vjerojatno neće biti prihvaćen!</translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>Generirano, ali nije prihvaćeno</translation>
@@ -1649,34 +1629,10 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Postavke:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Odaberi direktorij za datoteke</translation>
-    </message>
-    <message>
-        <source>Specify your own public address</source>
-        <translation>Odaberi vlastitu javnu adresu</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>Prihvati komande iz tekst moda i JSON-RPC</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>Izvršavaj u pozadini kao uslužnik i prihvaćaj komande</translation>
-    </message>
     <message>
         <source>Bitcoin Core</source>
         <translation>Bitcoin Core</translation>
     </message>
-    <message>
-        <source>Block creation options:</source>
-        <translation>Opcije za kreiranje bloka:</translation>
-    </message>
     <message>
         <source>Error: Disk space is low!</source>
         <translation>Pogreška: Nema dovoljno prostora na disku!</translation>
@@ -1685,30 +1641,10 @@
         <source>Information</source>
         <translation>Informacija</translation>
     </message>
-    <message>
-        <source>Send trace/debug info to console instead of debug.log file</source>
-        <translation>Šalji trace/debug informacije na konzolu umjesto u debug.log datoteku</translation>
-    </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>Korisničko ime za JSON-RPC veze</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Upozorenje</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>Lozinka za JSON-RPC veze</translation>
-    </message>
-    <message>
-        <source>Execute command when the best block changes (%s in cmd is replaced by block hash)</source>
-        <translation>Izvršite naredbu kada se najbolji blok promjeni (%s u cmd je zamjenjen sa block hash)</translation>
-    </message>
-    <message>
-        <source>Allow DNS lookups for -addnode, -seednode and -connect</source>
-        <translation>Dozvoli DNS upite za -addnode, -seednode i -connect</translation>
-    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Nedovoljna sredstva</translation>
