@@ -3,7 +3,7 @@
     <name>AddressBookPage</name>
     <message>
         <source>Right-click to edit address or label</source>
-        <translation>$Right-click to edit address or label</translation>
+        <translation>Кликните правой кнопкой мыши для редактирования адреса или метки</translation>
     </message>
     <message>
         <source>Create a new address</source>
@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Удалить выбранный адрес из списка</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Введите адрес или метку для поиска</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Экспортировать данные текущей вкладки в файл</translation>
@@ -313,6 +317,14 @@
         <source>Open &amp;URI...</source>
         <translation>Открыть &amp;URI...</translation>
     </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Кошелек:</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>Кошелек по умолчанию</translation>
+    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>Нажмите для отключения взаимодействия с сетью.</translation>
@@ -385,6 +397,14 @@
         <source>Encrypt the private keys that belong to your wallet</source>
         <translation>Зашифровать приватные ключи, принадлежащие вашему кошельку</translation>
     </message>
+    <message>
+        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
+        <translation>Подписывайте сообщения Bitcoin адресами чтобы подтвердить что это написали именно Вы</translation>
+    </message>
+    <message>
+        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
+        <translation>Проверяйте сообщения чтобы убедиться что они подписаны конкретными Bitcoin адресами</translation>
+    </message>
     <message>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
@@ -397,6 +417,22 @@
         <source>&amp;Help</source>
         <translation>&amp;Помощь</translation>
     </message>
+    <message>
+        <source>Tabs toolbar</source>
+        <translation>Панель вкладок</translation>
+    </message>
+    <message>
+        <source>Show the list of used sending addresses and labels</source>
+        <translation>Показать список использованных адресов и меток получателей</translation>
+    </message>
+    <message>
+        <source>Show the list of used receiving addresses and labels</source>
+        <translation>Показать список использованных адресов и меток получателей</translation>
+    </message>
+    <message>
+        <source>Open a bitcoin: URI or payment request</source>
+        <translation>Открыть биткойн: URI или запрос платежа</translation>
+    </message>
     <message>
         <source>&amp;Command-line options</source>
         <translation>Опции командной строки</translation>
@@ -417,6 +453,10 @@
         <source>Last received block was generated %1 ago.</source>
         <translation>Последний полученный блок был сгенерирован %1 назад.</translation>
     </message>
+    <message>
+        <source>Transactions after this will not yet be visible.</source>
+        <translation>После этого транзакции больше не будут видны.</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Ошибка</translation>
@@ -437,6 +477,10 @@
         <source>Connecting to peers...</source>
         <translation>Подключение к пирам...</translation>
     </message>
+    <message>
+        <source>Catching up...</source>
+        <translation>Синхронизация...</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
@@ -447,6 +491,12 @@
         <source>Amount: %1
 </source>
         <translation>Объем: %1
+</translation>
+    </message>
+    <message>
+        <source>Wallet: %1
+</source>
+        <translation>Кошелек: %1
 </translation>
     </message>
     <message>
@@ -461,6 +511,16 @@
         <translation>Ярлык: %1
 </translation>
     </message>
+    <message>
+        <source>Address: %1
+</source>
+        <translation>Адрес: %1
+</translation>
+    </message>
+    <message>
+        <source>Sent transaction</source>
+        <translation>Отправленная транзакция</translation>
+    </message>
     <message>
         <source>Incoming transaction</source>
         <translation>Входящая транзакция</translation>
@@ -480,6 +540,10 @@
 </context>
 <context>
     <name>CoinControlDialog</name>
+    <message>
+        <source>Coin Selection</source>
+        <translation>Выбор коинов</translation>
+    </message>
     <message>
         <source>Quantity:</source>
         <translation>Количество:</translation>
@@ -496,10 +560,38 @@
         <source>Fee:</source>
         <translation>Комиссия:</translation>
     </message>
+    <message>
+        <source>Dust:</source>
+        <translation>Пыль:</translation>
+    </message>
     <message>
         <source>After Fee:</source>
         <translation>После комиссии:</translation>
     </message>
+    <message>
+        <source>Change:</source>
+        <translation>Сдача:</translation>
+    </message>
+    <message>
+        <source>Tree mode</source>
+        <translation>Режим дерева</translation>
+    </message>
+    <message>
+        <source>List mode</source>
+        <translation>Режим списка</translation>
+    </message>
+    <message>
+        <source>Amount</source>
+        <translation>Количество</translation>
+    </message>
+    <message>
+        <source>Received with label</source>
+        <translation>Получено с меткой</translation>
+    </message>
+    <message>
+        <source>Received with address</source>
+        <translation>Получено с адресом</translation>
+    </message>
     <message>
         <source>Date</source>
         <translation>Дата</translation>
@@ -528,10 +620,38 @@
         <source>Copy transaction ID</source>
         <translation>Копировать ID транзакции</translation>
     </message>
+    <message>
+        <source>Lock unspent</source>
+        <translation>Заблокировать непотраченное</translation>
+    </message>
+    <message>
+        <source>Unlock unspent</source>
+        <translation>Разблокировать непотраченное</translation>
+    </message>
     <message>
         <source>Copy quantity</source>
         <translation>Копировать количество</translation>
     </message>
+    <message>
+        <source>Copy fee</source>
+        <translation>Скопировать комиссию</translation>
+    </message>
+    <message>
+        <source>Copy after fee</source>
+        <translation>Скопировать после комиссии</translation>
+    </message>
+    <message>
+        <source>Copy bytes</source>
+        <translation>Скопировать байты</translation>
+    </message>
+    <message>
+        <source>Copy dust</source>
+        <translation>Скопировать пыль</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>Скопировать сдачу</translation>
+    </message>
     <message>
         <source>yes</source>
         <translation>да</translation>
@@ -544,7 +664,11 @@
         <source>(no label)</source>
         <translation>(нет метки)</translation>
     </message>
-    </context>
+    <message>
+        <source>(change)</source>
+        <translation>(сдача)</translation>
+    </message>
+</context>
 <context>
     <name>EditAddressDialog</name>
     <message>
@@ -552,12 +676,12 @@
         <translation>Изменить адрес</translation>
     </message>
     <message>
-        <source>&amp;Address</source>
-        <translation>&amp;Адрес</translation>
+        <source>&amp;Label</source>
+        <translation>&amp;Метка</translation>
     </message>
     <message>
-        <source>New receiving address</source>
-        <translation>Новый адрес получения</translation>
+        <source>&amp;Address</source>
+        <translation>&amp;Адрес</translation>
     </message>
     <message>
         <source>New sending address</source>
@@ -582,6 +706,10 @@
         <source>A new data directory will be created.</source>
         <translation>Будет создана новая директория данных.</translation>
     </message>
+    <message>
+        <source>name</source>
+        <translation>имя</translation>
+    </message>
     <message>
         <source>Cannot create data directory here.</source>
         <translation>Невозможно создать директорию данных здесь.</translation>
@@ -601,34 +729,6 @@
         <source>Command-line options</source>
         <translation>Опции командной строки</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Использование:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>Опции командной строки</translation>
-    </message>
-    <message>
-        <source>Choose data directory on startup (default: %u)</source>
-        <translation>Выбрать директорию данных при запуске (по умолчанию: %u)</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>Задать язык, к примеру, "de_DE" (по умолчанию: язык системы)</translation>
-    </message>
-    <message>
-        <source>Start minimized</source>
-        <translation>Запускать свернутым</translation>
-    </message>
-    <message>
-        <source>Show splash screen on startup (default: %u)</source>
-        <translation>Отображать начальный экран во время запуска (значение по умолчанию: %u)</translation>
-    </message>
-    <message>
-        <source>Reset all settings changed in the GUI</source>
-        <translation>Выполнить сброс всех измененных настроек в GUI-интерфейсе</translation>
-    </message>
 </context>
 <context>
     <name>Intro</name>
@@ -675,6 +775,18 @@
     </context>
 <context>
     <name>ModalOverlay</name>
+    <message>
+        <source>Form</source>
+        <translation>Форма</translation>
+    </message>
+    <message>
+        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.</source>
+        <translation>Последние транзакции пока могут быть не видны, поэтому вы можете видеть некорректный баланс ваших кошельков. Отображаемая информация будет верна после завершения синхронизации. Прогресс синхронизации вы можете видеть ниже.</translation>
+    </message>
+    <message>
+        <source>Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
+        <translation>Попытка потратить средства, использованные в транзакциях, которые ещё не синхронизированы, будет отклонена сетью.</translation>
+    </message>
     <message>
         <source>Number of blocks left</source>
         <translation>Количество оставшихся блоков</translation>
@@ -683,10 +795,18 @@
         <source>Unknown...</source>
         <translation>Неизвестно...</translation>
     </message>
+    <message>
+        <source>Last block time</source>
+        <translation>Время последнего блока</translation>
+    </message>
     <message>
         <source>Progress</source>
         <translation>Прогресс</translation>
     </message>
+    <message>
+        <source>Progress increase per hour</source>
+        <translation>Прогресс за час</translation>
+    </message>
     <message>
         <source>calculating...</source>
         <translation>выполняется вычисление...</translation>
@@ -699,7 +819,11 @@
         <source>Hide</source>
         <translation>Спрятать</translation>
     </message>
-    </context>
+    <message>
+        <source>Unknown. Syncing Headers (%1)...</source>
+        <translation>Не известно. Синхронизация заголовков (%1)...</translation>
+    </message>
+</context>
 <context>
     <name>OpenURIDialog</name>
     <message>
@@ -710,7 +834,15 @@
         <source>URI:</source>
         <translation>URI:</translation>
     </message>
-    </context>
+    <message>
+        <source>Select payment request file</source>
+        <translation>Выберите файл запроса платежа</translation>
+    </message>
+    <message>
+        <source>Select payment request file to open</source>
+        <translation>Выберите файл запроса платежа для открытия</translation>
+    </message>
+</context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -757,6 +889,10 @@
         <source>&amp;Network</source>
         <translation>&amp;Сеть</translation>
     </message>
+    <message>
+        <source>GB</source>
+        <translation>ГБ</translation>
+    </message>
     <message>
         <source>W&amp;allet</source>
         <translation>К&amp;ошелёк</translation>
@@ -765,10 +901,22 @@
         <source>Expert</source>
         <translation>Эксперт</translation>
     </message>
+    <message>
+        <source>&amp;Spend unconfirmed change</source>
+        <translation>&amp;Тратить неподтвержденную сдачу</translation>
+    </message>
     <message>
         <source>Map port using &amp;UPnP</source>
         <translation>Пробросить порт через &amp;UPnP</translation>
     </message>
+    <message>
+        <source>Accept connections from outside.</source>
+        <translation>Принимать внешние подключения</translation>
+    </message>
+    <message>
+        <source>Allow incomin&amp;g connections</source>
+        <translation>Разрешить входящие соединения</translation>
+    </message>
     <message>
         <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
         <translation>Подключится к сети Bitcoin через SOCKS5 прокси.</translation>
@@ -809,6 +957,18 @@
         <source>Show only a tray icon after minimizing the window.</source>
         <translation>Отобразить только значок в области уведомлений после сворачивания окна.</translation>
     </message>
+    <message>
+        <source>User Interface &amp;language:</source>
+        <translation>Язык пользовательского интерфейса:</translation>
+    </message>
+    <message>
+        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
+        <translation>Здесь можно выбрать язык пользовательского интерфейса. Параметры будут применены после перезапуска %1</translation>
+    </message>
+    <message>
+        <source>Whether to show coin control features or not.</source>
+        <translation>Показывать ли опцию управления монетами.</translation>
+    </message>
     <message>
         <source>&amp;OK</source>
         <translation>&amp;ОК</translation>
@@ -817,6 +977,10 @@
         <source>&amp;Cancel</source>
         <translation>&amp;Отмена</translation>
     </message>
+    <message>
+        <source>default</source>
+        <translation>по умолчанию</translation>
+    </message>
     <message>
         <source>Confirm options reset</source>
         <translation>Подтвердить сброс опций</translation>
@@ -852,6 +1016,18 @@
 </context>
 <context>
     <name>OverviewPage</name>
+    <message>
+        <source>Form</source>
+        <translation>Форма</translation>
+    </message>
+    <message>
+        <source>Your current spendable balance</source>
+        <translation>Ваш доступный баланс</translation>
+    </message>
+    <message>
+        <source>Pending:</source>
+        <translation>В ожидании:</translation>
+    </message>
     <message>
         <source>Immature:</source>
         <translation>Незрелые:</translation>
@@ -872,6 +1048,10 @@
         <source>Your current balance in watch-only addresses</source>
         <translation>Ваш текущий баланс (только чтение):</translation>
     </message>
+    <message>
+        <source>Spendable:</source>
+        <translation>Доступно:</translation>
+    </message>
     <message>
         <source>Recent transactions</source>
         <translation>Последние транзакции</translation>
@@ -879,6 +1059,30 @@
     </context>
 <context>
     <name>PaymentServer</name>
+    <message>
+        <source>Payment request error</source>
+        <translation>Ошибка запроса платежа</translation>
+    </message>
+    <message>
+        <source>Invalid payment address %1</source>
+        <translation>Неверный адрес %1</translation>
+    </message>
+    <message>
+        <source>Payment request rejected</source>
+        <translation>Запрос платежа отклонен</translation>
+    </message>
+    <message>
+        <source>Payment request expired.</source>
+        <translation>Истекло время ожидания запроса платежа</translation>
+    </message>
+    <message>
+        <source>Payment request is not initialized.</source>
+        <translation>Запрос платежа не инициализирован</translation>
+    </message>
+    <message>
+        <source>Invalid payment request.</source>
+        <translation>Неверный запрос платежа.</translation>
+    </message>
     <message>
         <source>Error communicating with %1: %2</source>
         <translation>Ошибка связи с %1: %2</translation>
@@ -894,10 +1098,18 @@
 </context>
 <context>
     <name>PeerTableModel</name>
+    <message>
+        <source>User Agent</source>
+        <translation>Пользовательский агент</translation>
+    </message>
     <message>
         <source>Node/Service</source>
         <translation>Узел/служба</translation>
     </message>
+    <message>
+        <source>NodeId</source>
+        <translation>Идентификатор узла</translation>
+    </message>
     <message>
         <source>Sent</source>
         <translation>Отправлено</translation>
@@ -909,6 +1121,10 @@
 </context>
 <context>
     <name>QObject</name>
+    <message>
+        <source>Amount</source>
+        <translation>Количество</translation>
+    </message>
     <message>
         <source>Enter a Bitcoin address (e.g. %1)</source>
         <translation>Введите биткоин-адрес (напр. %1)</translation>
@@ -1034,6 +1250,10 @@
         <source>Memory usage</source>
         <translation>Использование памяти</translation>
     </message>
+    <message>
+        <source>Wallet: </source>
+        <translation>Кошелек:</translation>
+    </message>
     <message>
         <source>&amp;Reset</source>
         <translation>&amp;Сбросить</translation>
@@ -1058,6 +1278,18 @@
         <source>Version</source>
         <translation>Версия</translation>
     </message>
+    <message>
+        <source>Synced Headers</source>
+        <translation>Синхронизировано заголовков</translation>
+    </message>
+    <message>
+        <source>Synced Blocks</source>
+        <translation>Синхронизировано блоков</translation>
+    </message>
+    <message>
+        <source>User Agent</source>
+        <translation>Пользовательский агент</translation>
+    </message>
     <message>
         <source>Decrease font size</source>
         <translation>Уменьшить размер шрифта</translation>
@@ -1066,6 +1298,34 @@
         <source>Increase font size</source>
         <translation>Увеличить размер шрифта</translation>
     </message>
+    <message>
+        <source>Services</source>
+        <translation>Сервисы</translation>
+    </message>
+    <message>
+        <source>Connection Time</source>
+        <translation>Время соединения</translation>
+    </message>
+    <message>
+        <source>Last Send</source>
+        <translation>Последние отправленные</translation>
+    </message>
+    <message>
+        <source>Last Receive</source>
+        <translation>Последние полученные</translation>
+    </message>
+    <message>
+        <source>Ping Time</source>
+        <translation>Время отклика Ping</translation>
+    </message>
+    <message>
+        <source>Min Ping</source>
+        <translation>Минимальное время отклика Ping</translation>
+    </message>
+    <message>
+        <source>Last block time</source>
+        <translation>Время последнего блока</translation>
+    </message>
     <message>
         <source>&amp;Open</source>
         <translation>&amp;Открыть</translation>
@@ -1074,6 +1334,18 @@
         <source>&amp;Console</source>
         <translation>&amp;Консоль</translation>
     </message>
+    <message>
+        <source>&amp;Network Traffic</source>
+        <translation>&amp;Сетевой трафик</translation>
+    </message>
+    <message>
+        <source>In:</source>
+        <translation>Вход:</translation>
+    </message>
+    <message>
+        <source>Out:</source>
+        <translation>Выход:</translation>
+    </message>
     <message>
         <source>1 &amp;hour</source>
         <translation>1 &amp;час</translation>
@@ -1090,6 +1362,10 @@
         <source>1 &amp;year</source>
         <translation>1 &amp;год</translation>
     </message>
+    <message>
+        <source>default wallet</source>
+        <translation>Кошелек по умолчанию</translation>
+    </message>
     <message>
         <source>Type %1 for an overview of available commands.</source>
         <translation>Ввести %1 для обзора доступных команд.</translation>
@@ -1113,6 +1389,14 @@
 </context>
 <context>
     <name>ReceiveCoinsDialog</name>
+    <message>
+        <source>&amp;Label:</source>
+        <translation>&amp;Метка:</translation>
+    </message>
+    <message>
+        <source>&amp;Message:</source>
+        <translation>&amp;Сообщение:</translation>
+    </message>
     <message>
         <source>Clear all fields of the form.</source>
         <translation>Очистить все поля формы.</translation>
@@ -1121,6 +1405,14 @@
         <source>Clear</source>
         <translation>Отчистить</translation>
     </message>
+    <message>
+        <source>Requested payments history</source>
+        <translation>История платежных запросов</translation>
+    </message>
+    <message>
+        <source>&amp;Request payment</source>
+        <translation>&amp;Запросить платеж</translation>
+    </message>
     <message>
         <source>Show the selected request (does the same as double clicking an entry)</source>
         <translation>Отобразить выбранный запрос (выполняет то же, что и двойной щелчок на записи)</translation>
@@ -1160,6 +1452,14 @@
         <source>QR Code</source>
         <translation>QR-код</translation>
     </message>
+    <message>
+        <source>Copy &amp;URI</source>
+        <translation>Копировать &amp;URI</translation>
+    </message>
+    <message>
+        <source>Copy &amp;Address</source>
+        <translation>Копировать &amp;Адрес</translation>
+    </message>
     <message>
         <source>&amp;Save Image...</source>
         <translation>&amp;Сохранить изображение...</translation>
@@ -1168,10 +1468,18 @@
         <source>Payment information</source>
         <translation>Информация о платеже</translation>
     </message>
+    <message>
+        <source>URI</source>
+        <translation>URI</translation>
+    </message>
     <message>
         <source>Address</source>
         <translation>Адрес</translation>
     </message>
+    <message>
+        <source>Amount</source>
+        <translation>Количество</translation>
+    </message>
     <message>
         <source>Label</source>
         <translation>Метка</translation>
@@ -1180,6 +1488,10 @@
         <source>Message</source>
         <translation>Сообщение</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Кошелек</translation>
+    </message>
     <message>
         <source>Error encoding URI into QR Code.</source>
         <translation>Ошибка преобразования URI в QR-код.</translation>
@@ -1207,17 +1519,37 @@
         <source>(no message)</source>
         <translation>(нет сообщений)</translation>
     </message>
-    </context>
+    <message>
+        <source>(no amount requested)</source>
+        <translation>(не указана запрашиваемая сумма)</translation>
+    </message>
+    <message>
+        <source>Requested</source>
+        <translation>Запрошено</translation>
+    </message>
+</context>
 <context>
     <name>SendCoinsDialog</name>
     <message>
         <source>Send Coins</source>
         <translation>Отправить монеты</translation>
     </message>
+    <message>
+        <source>Coin Control Features</source>
+        <translation>Опции управления монетами</translation>
+    </message>
+    <message>
+        <source>Inputs...</source>
+        <translation>Входы...</translation>
+    </message>
     <message>
         <source>automatically selected</source>
         <translation>выбрано автоматически</translation>
     </message>
+    <message>
+        <source>Insufficient funds!</source>
+        <translation>Недостаточно средств!</translation>
+    </message>
     <message>
         <source>Quantity:</source>
         <translation>Количество:</translation>
@@ -1238,6 +1570,14 @@
         <source>After Fee:</source>
         <translation>После комиссии:</translation>
     </message>
+    <message>
+        <source>Change:</source>
+        <translation>Сдача:</translation>
+    </message>
+    <message>
+        <source>Custom change address</source>
+        <translation>Указать адрес для сдачи</translation>
+    </message>
     <message>
         <source>Transaction Fee:</source>
         <translation>Комиссия за транзакцию:</translation>
@@ -1246,6 +1586,18 @@
         <source>Choose...</source>
         <translation>Выбрать...</translation>
     </message>
+    <message>
+        <source>Warning: Fee estimation is currently not possible.</source>
+        <translation>Предупреждение: оценка комиссии в данный момент невозможна.</translation>
+    </message>
+    <message>
+        <source>collapse fee-settings</source>
+        <translation>свернуть настройки комиссионных</translation>
+    </message>
+    <message>
+        <source>per kilobyte</source>
+        <translation>за килобайт</translation>
+    </message>
     <message>
         <source>Hide</source>
         <translation>Спрятать</translation>
@@ -1262,10 +1614,26 @@
         <source>Send to multiple recipients at once</source>
         <translation>Отправить нескольким получателям сразу</translation>
     </message>
+    <message>
+        <source>Add &amp;Recipient</source>
+        <translation>Добавить &amp;получателя</translation>
+    </message>
     <message>
         <source>Clear all fields of the form.</source>
         <translation>Очистить все поля формы.</translation>
     </message>
+    <message>
+        <source>Dust:</source>
+        <translation>Пыль:</translation>
+    </message>
+    <message>
+        <source>Confirmation time target:</source>
+        <translation>Целевое время подтверждения</translation>
+    </message>
+    <message>
+        <source>Enable Replace-By-Fee</source>
+        <translation>Включить Replace-By-Fee</translation>
+    </message>
     <message>
         <source>Balance:</source>
         <translation>Баланс:</translation>
@@ -1278,6 +1646,26 @@
         <source>Copy amount</source>
         <translation>Копировать сумму</translation>
     </message>
+    <message>
+        <source>Copy fee</source>
+        <translation>Скопировать комиссию</translation>
+    </message>
+    <message>
+        <source>Copy after fee</source>
+        <translation>Скопировать после комиссии</translation>
+    </message>
+    <message>
+        <source>Copy bytes</source>
+        <translation>Скопировать байты</translation>
+    </message>
+    <message>
+        <source>Copy dust</source>
+        <translation>Скопировать пыль</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>Скопировать сдачу</translation>
+    </message>
     <message>
         <source>Are you sure you want to send?</source>
         <translation>Вы действительно хотите выполнить отправку?</translation>
@@ -1286,6 +1674,10 @@
         <source>or</source>
         <translation>или</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Комиссия</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Подтвердить отправку монет</translation>
@@ -1310,6 +1702,10 @@
         <source>A fee higher than %1 is considered an absurdly high fee.</source>
         <translation>Комиссия более чем в %1 считается абсурдно высокой.</translation>
     </message>
+    <message>
+        <source>Payment request expired.</source>
+        <translation>Истекло время ожидания запроса платежа</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(нет метки)</translation>
@@ -1317,6 +1713,10 @@
 </context>
 <context>
     <name>SendCoinsEntry</name>
+    <message>
+        <source>&amp;Label:</source>
+        <translation>&amp;Метка:</translation>
+    </message>
     <message>
         <source>Choose previously used address</source>
         <translation>Выбрать предыдущий использованный адрес</translation>
@@ -1419,6 +1819,14 @@
     </context>
 <context>
     <name>TransactionDesc</name>
+    <message>
+        <source>in memory pool</source>
+        <translation>в мемпуле</translation>
+    </message>
+    <message>
+        <source>not in memory pool</source>
+        <translation>не в мемпуле</translation>
+    </message>
     <message>
         <source>Status</source>
         <translation>Статус</translation>
@@ -1439,10 +1847,34 @@
         <source>unknown</source>
         <translation>неизвестно</translation>
     </message>
+    <message>
+        <source>watch-only</source>
+        <translation>только просмотр</translation>
+    </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Комиссия</translation>
+    </message>
     <message>
         <source>Message</source>
         <translation>Сообщение</translation>
     </message>
+    <message>
+        <source>Comment</source>
+        <translation>Комментарий</translation>
+    </message>
+    <message>
+        <source>Transaction ID</source>
+        <translation>ID транзакции</translation>
+    </message>
+    <message>
+        <source>Transaction</source>
+        <translation>Транзакция</translation>
+    </message>
+    <message>
+        <source>Amount</source>
+        <translation>Количество</translation>
+    </message>
     </context>
 <context>
     <name>TransactionDescDialog</name>
@@ -1465,6 +1897,22 @@
         <source>Label</source>
         <translation>Метка</translation>
     </message>
+    <message>
+        <source>Received with</source>
+        <translation>Получено на</translation>
+    </message>
+    <message>
+        <source>Sent to</source>
+        <translation>Отправить</translation>
+    </message>
+    <message>
+        <source>Mined</source>
+        <translation>Добыто</translation>
+    </message>
+    <message>
+        <source>watch-only</source>
+        <translation>только просмотр</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(нет метки)</translation>
@@ -1484,6 +1932,62 @@
     </context>
 <context>
     <name>TransactionView</name>
+    <message>
+        <source>All</source>
+        <translation>Все</translation>
+    </message>
+    <message>
+        <source>Today</source>
+        <translation>Сегодня</translation>
+    </message>
+    <message>
+        <source>This week</source>
+        <translation>Эта неделя</translation>
+    </message>
+    <message>
+        <source>This month</source>
+        <translation>Этот месяц</translation>
+    </message>
+    <message>
+        <source>Last month</source>
+        <translation>Последний месяц</translation>
+    </message>
+    <message>
+        <source>This year</source>
+        <translation>Этот год</translation>
+    </message>
+    <message>
+        <source>Range...</source>
+        <translation>Диапазон...</translation>
+    </message>
+    <message>
+        <source>Received with</source>
+        <translation>Получено на</translation>
+    </message>
+    <message>
+        <source>Sent to</source>
+        <translation>Отправить</translation>
+    </message>
+    <message>
+        <source>To yourself</source>
+        <translation>Себе</translation>
+    </message>
+    <message>
+        <source>Mined</source>
+        <translation>Добыто</translation>
+    </message>
+    <message>
+        <source>Enter address, transaction id, or label to search</source>
+        <translation>Введите адрес, ID транзакции или метку для поиска</translation>
+    </message>
+    <message>
+        <source>Min amount</source>
+        <translation>Минимальное количество</translation>
+    </message>
+    <message>
+        <source>Abandon transaction</source>
+        <translation>Отказ от транзакции</translation>
+    </message>
     <message>
         <source>Increase transaction fee</source>
         <translation>Увеличить комиссию за транзакцию</translation>
@@ -1504,14 +2008,26 @@
         <source>Copy transaction ID</source>
         <translation>Копировать ID транзакции</translation>
     </message>
+    <message>
+        <source>Copy raw transaction</source>
+        <translation>Копировать raw транзакцию</translation>
+    </message>
     <message>
         <source>Copy full transaction details</source>
         <translation>Копировать все детали транзакции</translation>
     </message>
+    <message>
+        <source>Edit label</source>
+        <translation>Изменить метку</translation>
+    </message>
     <message>
         <source>Show transaction details</source>
         <translation>Отобразить детали транзакции</translation>
     </message>
+    <message>
+        <source>Confirmed</source>
+        <translation>Подтвержденные</translation>
+    </message>
     <message>
         <source>Date</source>
         <translation>Дата</translation>
@@ -1624,17 +2140,9 @@
         <source>The wallet data was successfully saved to %1.</source>
         <translation>Данные кошелька были успешно сохранены в %1.</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Опции:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Указать директорию данных</translation>
-    </message>
     <message>
         <source>Error: A fatal internal error occurred, see debug.log for details</source>
         <translation>Ошибка: произошла критическая внутренняя ошибка, для получения деталей см. debug.log</translation>
@@ -1655,10 +2163,6 @@
         <source>%d of last 100 blocks have unexpected version</source>
         <translation>%d из последних 100 блоков имеют неожиданную версию</translation>
     </message>
-    <message>
-        <source>Connection options:</source>
-        <translation>Опции соединения:</translation>
-    </message>
     <message>
         <source>Copyright (C) %i-%i</source>
         <translation>Авторское право (©) %i-%i</translation>
@@ -1687,25 +2191,17 @@
         <source>Loading P2P addresses...</source>
         <translation>Выполняется загрузка P2P-адресов...</translation>
     </message>
+    <message>
+        <source>Loading banlist...</source>
+        <translation>Загрузка черного списка...</translation>
+    </message>
     <message>
         <source>Not enough file descriptors available.</source>
         <translation>Недоступно достаточного количества дескрипторов файла.</translation>
     </message>
     <message>
-        <source>Only connect to nodes in network &lt;net&gt; (ipv4, ipv6 or onion)</source>
-        <translation>Подключаться только к узлам в сети &lt;net&gt; (ipv4, ipv6 или onion)</translation>
-    </message>
-    <message>
-        <source>Print this help message and exit</source>
-        <translation>Распечатать это сообщение справки и выйти</translation>
-    </message>
-    <message>
-        <source>Print version and exit</source>
-        <translation>Распечатать версию и выйти</translation>
-    </message>
-    <message>
-        <source>Specify wallet file (within data directory)</source>
-        <translation>Указать файл кошелька (в пределах директории данных)</translation>
+        <source>Transaction fee and change calculation failed</source>
+        <translation>Не удалось рассчитать комиссию и сдачу для транзакции </translation>
     </message>
     <message>
         <source>Unsupported argument -debugnet ignored, use -debug=net.</source>
@@ -1716,20 +2212,8 @@
         <translation>Обнаружен неподдерживаемый аргумент -tor, необходимо использовать -onion.</translation>
     </message>
     <message>
-        <source>Wallet options:</source>
-        <translation>Опции кошелька:</translation>
-    </message>
-    <message>
-        <source>Whitelisted peers cannot be DoS banned and their transactions are always relayed, even if they are already in the mempool, useful e.g. for a gateway</source>
-        <translation>bitcoin-core</translation>
-    </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(значение по умолчанию: %u)</translation>
-    </message>
-    <message>
-        <source>Connect through SOCKS5 proxy</source>
-        <translation>Выполнить подключение через прокси-сервер SOCKS5</translation>
+        <source>Verifying blocks...</source>
+        <translation>Проверка блоков...</translation>
     </message>
     <message>
         <source>Error reading from database, shutting down.</source>
@@ -1743,17 +2227,41 @@
         <source>Signing transaction failed</source>
         <translation>Подписание транзакции завершилось неудачей</translation>
     </message>
+    <message>
+        <source>Transaction amount too small</source>
+        <translation>Размер транзакции слишком мал</translation>
+    </message>
+    <message>
+        <source>Transaction too large</source>
+        <translation>Транзакция слишком большая</translation>
+    </message>
     <message>
         <source>Warning</source>
         <translation>Предупреждение</translation>
     </message>
     <message>
-        <source>Do not keep transactions in the mempool longer than &lt;n&gt; hours (default: %u)</source>
-        <translation>Do not keep transactions in the mempool longer than &lt;n&gt; hours (default: %u)</translation>
+        <source>This is the minimum transaction fee you pay on every transaction.</source>
+        <translation>Это минимальная комиссия, которую вы платите для любой транзакции</translation>
     </message>
     <message>
-        <source>(default: %s)</source>
-        <translation>(значение по умолчанию: %s)</translation>
+        <source>This is the transaction fee you will pay if you send a transaction.</source>
+        <translation>Это размер комиссии, которую вы заплатите при отправке транзакции </translation>
+    </message>
+    <message>
+        <source>Transaction amounts must not be negative</source>
+        <translation>Размер транзакции не может быть отрицательным</translation>
+    </message>
+    <message>
+        <source>Transaction must have at least one recipient</source>
+        <translation>Транзакция должна иметь хотя бы одного получателя</translation>
+    </message>
+    <message>
+        <source>Insufficient funds</source>
+        <translation>Недостаточно средств</translation>
+    </message>
+    <message>
+        <source>Loading block index...</source>
+        <translation>Загрузка индекса блоков...</translation>
     </message>
     <message>
         <source>Loading wallet...</source>
