@@ -37,6 +37,14 @@
         <source>Choose the address to send coins to</source>
         <translation>Zgjidh adresen ku do te dergoni monedhat</translation>
     </message>
+    <message>
+        <source>Choose the address to receive coins with</source>
+        <translation>Zgjidh adresën ku do të merrni monedhat</translation>
+    </message>
+    <message>
+        <source>C&amp;hoose</source>
+        <translation>Zgjidh</translation>
+    </message>
     <message>
         <source>Sending addresses</source>
         <translation>Duke derguar adresen</translation>
@@ -101,15 +109,19 @@
     <name>AskPassphraseDialog</name>
     <message>
         <source>Enter passphrase</source>
-        <translation>Futni frazkalimin</translation>
+        <translation>Futni fjalëkalimin</translation>
     </message>
     <message>
         <source>New passphrase</source>
-        <translation>Frazkalim i ri</translation>
+        <translation>Fjalëkalimi i ri</translation>
     </message>
     <message>
         <source>Repeat new passphrase</source>
-        <translation>Përsërisni frazkalimin e ri</translation>
+        <translation>Përsërisni fjalëkalimin e ri</translation>
+    </message>
+    <message>
+        <source>Show password</source>
+        <translation>Trego fjalëkalimin</translation>
     </message>
     <message>
         <source>Encrypt wallet</source>
@@ -117,11 +129,11 @@
     </message>
     <message>
         <source>This operation needs your wallet passphrase to unlock the wallet.</source>
-        <translation>Ky veprim ka nevojë per frazkalimin e portofolit tuaj që të ç'kyç portofolin.</translation>
+        <translation>Ky veprim ka nevojë per fjalëkalimin e portofolit tuaj që të hapë portofolin.</translation>
     </message>
     <message>
         <source>Unlock wallet</source>
-        <translation>ç'kyç portofolin.</translation>
+        <translation>Hap portofolin.</translation>
     </message>
     <message>
         <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
@@ -133,7 +145,11 @@
     </message>
     <message>
         <source>Change passphrase</source>
-        <translation>Ndrysho frazkalimin</translation>
+        <translation>Ndrysho fjalëkalimin</translation>
+    </message>
+    <message>
+        <source>Enter the old passphrase and new passphrase to the wallet.</source>
+        <translation>Fusni fjalëkalimin e vjetër dhe fjalëkalimin e ri që të hapni portofolin.</translation>
     </message>
     <message>
         <source>Confirm wallet encryption</source>
@@ -335,10 +351,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Adresa</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Adresë e re pritëse</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Adresë e re dërgimi</translation>
@@ -351,10 +363,6 @@
         <source>Edit sending address</source>
         <translation>ndrysho adresën dërguese</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Adresa e dhënë "%1" është e zënë në librin e adresave. </translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Nuk mund të ç'kyçet portofoli.</translation>
@@ -384,6 +392,10 @@
         <source>Welcome</source>
         <translation>Miresevini</translation>
     </message>
+    <message>
+        <source>Bitcoin</source>
+        <translation>Bitcoin</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Problem</translation>
@@ -409,6 +421,10 @@
         <source>W&amp;allet</source>
         <translation>Portofol</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Problem</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -433,7 +449,11 @@
         <source>%1 and %2</source>
         <translation>%1 dhe %2</translation>
     </message>
-    </context>
+    <message>
+        <source>unknown</source>
+        <translation>i/e panjohur</translation>
+    </message>
+</context>
 <context>
     <name>QObject::QObject</name>
     </context>
@@ -450,10 +470,6 @@
         <source>&amp;Open</source>
         <translation>&amp;Hap</translation>
     </message>
-    <message>
-        <source>&amp;Clear</source>
-        <translation>&amp;Pastro</translation>
-    </message>
     <message>
         <source>never</source>
         <translation>asnjehere</translation>
@@ -496,6 +512,10 @@
         <source>Label</source>
         <translation>Etiketë</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Portofol</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -631,10 +651,6 @@
         <source>%1 confirmations</source>
         <translation>%1 konfirmimet</translation>
     </message>
-    <message>
-        <source>, has not been successfully broadcast yet</source>
-        <translation>, nuk është transmetuar me sukses deri tani</translation>
-    </message>
     <message>
         <source>Date</source>
         <translation>Data</translation>
@@ -681,10 +697,6 @@
         <source>Confirmed (%1 confirmations)</source>
         <translation>I/E konfirmuar(%1 konfirmime)</translation>
     </message>
-    <message>
-        <source>This block was not received by any other nodes and will probably not be accepted!</source>
-        <translation>Ky bllok është marrë nga ndonjë nyje dhe ka shumë mundësi të mos pranohet! </translation>
-    </message>
     <message>
         <source>Generated but not accepted</source>
         <translation>I krijuar por i papranuar</translation>
@@ -769,7 +781,7 @@
         <source>Send Coins</source>
         <translation>Dërgo Monedha</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>WalletView</name>
     <message>
@@ -779,10 +791,6 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opsionet:</translation>
-    </message>
     <message>
         <source>Bitcoin Core</source>
         <translation>Berthama Bitcoin</translation>
