@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Жорий танланган манзилни рўйхатдан ўчириш</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Излаш учун манзил ёки ёрлиқни киритинг</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Жорий ички ойна ичидаги маълумотларни файлга экспорт қилиш</translation>
@@ -245,30 +249,6 @@
         <source>%n active connection(s) to Bitcoin network</source>
         <translation><numerusform>%n та Bitcoin тармоғига фаол уланиш мавжуд</numerusform></translation>
     </message>
-    <message>
-        <source>No block source available...</source>
-        <translation>Блок манбалари мавжуд эмас...</translation>
-    </message>
-    <message numerus="yes">
-        <source>%n hour(s)</source>
-        <translation><numerusform>%n соат</numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n day(s)</source>
-        <translation><numerusform>%n кун</numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n week(s)</source>
-        <translation><numerusform>%n ҳафта</numerusform></translation>
-    </message>
-    <message>
-        <source>%1 and %2</source>
-        <translation>%1 ва %2</translation>
-    </message>
-    <message numerus="yes">
-        <source>%n year(s)</source>
-        <translation><numerusform>%n йил</numerusform></translation>
-    </message>
     <message>
         <source>%1 behind</source>
         <translation>%1 орқада</translation>
@@ -317,7 +297,7 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Ҳамён &lt;b&gt;кодланган&lt;/b&gt; ва вақтинча &lt;b&gt;қулфланган&lt;/b&gt;</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -332,10 +312,6 @@
         <source>Amount:</source>
         <translation>Миқдори:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Муҳимлиги:</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Солиқ:</translation>
@@ -380,10 +356,6 @@
         <source>Confirmed</source>
         <translation>Тасдиқланди</translation>
     </message>
-    <message>
-        <source>Priority</source>
-        <translation>Муҳимлиги</translation>
-    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -445,15 +417,7 @@
         <source>Command-line options</source>
         <translation>Буйруқлар сатри мосламалари</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Фойдаланиш:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>буйруқлар қатори орқали мослаш</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -468,6 +432,10 @@
         <source>Use a custom data directory:</source>
         <translation>Бошқа маълумотлар директориясида фойдаланинг:</translation>
     </message>
+    <message>
+        <source>Bitcoin</source>
+        <translation>Bitcoin</translation>
+    </message>
     <message>
         <source>Error: Specified data directory "%1" cannot be created.</source>
         <translation>Хато: кўрсатилган "%1" маълумотлар директориясини яратиб бўлмайди.</translation>
@@ -477,6 +445,17 @@
         <translation>Хатолик</translation>
     </message>
     </context>
+<context>
+    <name>ModalOverlay</name>
+    <message>
+        <source>Form</source>
+        <translation>Шакл</translation>
+    </message>
+    <message>
+        <source>Last block time</source>
+        <translation>Сўнгги блок вақти</translation>
+    </message>
+    </context>
 <context>
     <name>OpenURIDialog</name>
     <message>
@@ -518,22 +497,10 @@
         <source>Number of script &amp;verification threads</source>
         <translation>Мавзуларни &amp;тўғрилаш скрипти миқдори</translation>
     </message>
-    <message>
-        <source>Accept connections from outside</source>
-        <translation>Ташқаридан уланишларга рози бўлиш</translation>
-    </message>
-    <message>
-        <source>Allow incoming connections</source>
-        <translation>Кирувчи уланишларга рухсат бериш</translation>
-    </message>
     <message>
         <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
         <translation>Прокси IP манзили (масалан: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
     </message>
-    <message>
-        <source>Third party transaction URLs</source>
-        <translation>Бегона тараф ўтказмалари URL манзиллари</translation>
-    </message>
     <message>
         <source>&amp;Network</source>
         <translation>Тармоқ</translation>
@@ -606,6 +573,10 @@
         <source>Client restart required to activate changes.</source>
         <translation>Ўзгаришлар амалга ошиши учун мижозни қайта ишга тушириш талаб қилинади.</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Хатолик</translation>
+    </message>
     <message>
         <source>This change would require a client restart.</source>
         <translation>Ушбу ўзгариш мижозни қайтадан ишга туширишни талаб қилади.</translation>
@@ -695,11 +666,7 @@
         <source>User Agent</source>
         <translation>Фойдаланувчи вакил</translation>
     </message>
-    <message>
-        <source>Ping Time</source>
-        <translation>Ping вақти</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>QObject</name>
     <message>
@@ -730,7 +697,34 @@
         <source>%1 ms</source>
         <translation>%1 мс</translation>
     </message>
+    <message>
+        <source>%1 and %2</source>
+        <translation>%1 ва %2</translation>
+    </message>
+    <message>
+        <source>%1 B</source>
+        <translation>%1 Б</translation>
+    </message>
+    <message>
+        <source>%1 KB</source>
+        <translation>%1 КБ</translation>
+    </message>
+    <message>
+        <source>%1 MB</source>
+        <translation>%1 МБ</translation>
+    </message>
+    <message>
+        <source>%1 GB</source>
+        <translation>%1 ГБ</translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation>Номаълум</translation>
+    </message>
 </context>
+<context>
+    <name>QObject::QObject</name>
+    </context>
 <context>
     <name>QRImageWidget</name>
     </context>
@@ -832,10 +826,6 @@
         <source>&amp;Network Traffic</source>
         <translation>&amp;Тармоқ трафиги</translation>
     </message>
-    <message>
-        <source>&amp;Clear</source>
-        <translation>&amp;Тозалаш</translation>
-    </message>
     <message>
         <source>Totals</source>
         <translation>Жами</translation>
@@ -856,30 +846,6 @@
         <source>Clear console</source>
         <translation>Терминални тозалаш</translation>
     </message>
-    <message>
-        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
-        <translation>Тарихни кўриш учун тепага ва пастга кўрсаткичларидан фойдаланинг, экранни тозалаш учун &lt;b&gt;Ctrl-L&lt;/b&gt; тугмалар бирикмасидан фойдаланинг.</translation>
-    </message>
-    <message>
-        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
-        <translation>Мавжуд буйруқларни кўриш учун &lt;b&gt;help&lt;/b&gt; деб ёзинг.</translation>
-    </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 Б</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 КБ</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 МБ</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 ГБ</translation>
-    </message>
     <message>
         <source>via %1</source>
         <translation>%1 орқали</translation>
@@ -923,10 +889,6 @@
         <source>&amp;Message:</source>
         <translation>&amp;Хабар:</translation>
     </message>
-    <message>
-        <source>Reuse one of the previously used receiving addresses. Reusing addresses has security and privacy issues. Do not use this unless re-generating a payment request made before.</source>
-        <translation>Олдинги фойдаланилган қабул қилинган манзиллардан биридан қайта фойдаланилсин. Хавсизлик ва махфийлик муаммолар мавжуд манзиллардан қайта фойдаланилмоқда. Бундан тўлов сўров қайта яратилмагунича фойдаланманг.</translation>
-    </message>
     <message>
         <source>An optional label to associate with the new receiving address.</source>
         <translation>Янги қабул қилинаётган манзил билан боғланган танланадиган ёрлиқ.</translation>
@@ -986,6 +948,10 @@
         <source>&amp;Save Image...</source>
         <translation>Расмни &amp;сақлаш</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Ҳамён</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1020,10 +986,6 @@
         <source>Amount:</source>
         <translation>Миқдори:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Муҳимлиги:</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Солиқ:</translation>
@@ -1060,18 +1022,6 @@
         <source>Recommended:</source>
         <translation>Тавсия этилган</translation>
     </message>
-    <message>
-        <source>Confirmation time:</source>
-        <translation>Тасдиқ вақти</translation>
-    </message>
-    <message>
-        <source>normal</source>
-        <translation>Нормал</translation>
-    </message>
-    <message>
-        <source>fast</source>
-        <translation>Тезкор</translation>
-    </message>
     <message>
         <source>Send to multiple recipients at once</source>
         <translation>Бирданига бир нечта қабул қилувчиларга жўнатиш</translation>
@@ -1100,6 +1050,10 @@
         <source>S&amp;end</source>
         <translation>Жў&amp;натиш</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Ўтказма тўлови</translation>
+    </message>
     </context>
 <context>
     <name>SendCoinsEntry</name>
@@ -1217,50 +1171,18 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Танламалар:</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Маълумотлар директориясини кўрсатинг</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>Буйруқлар сатри ва JSON-RPC буйруқларига рози бўлинг</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>Демон сифатида орқа фонда ишга туширинг ва буйруқларга рози бўлинг</translation>
-    </message>
     <message>
         <source>Bitcoin Core</source>
         <translation>Bitcoin Core</translation>
     </message>
-    <message>
-        <source>Connection options:</source>
-        <translation>Уланиш кўрсаткичлари:</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Маълумот</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>JSON-RPC уланишлари учун фойдаланувчи номи</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Диққат</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>JSON-RPC уланишлари учун парол</translation>
-    </message>
-    <message>
-        <source>Loading addresses...</source>
-        <translation>Манзиллар юкланмоқда...</translation>
-    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Кам миқдор</translation>
