@@ -1,4 +1,4 @@
-// Copyright (c) 2013-2017 The Bitcoin Core developers
+// Copyright (c) 2013-2018 The Bitcoin Core developers
 // Distributed under the MIT software license, see the accompanying
 // file COPYING or http://www.opensource.org/licenses/mit-license.php.
 
@@ -25,22 +25,22 @@ BOOST_AUTO_TEST_CASE(murmurhash3)
     //
     // The magic number 0xFBA4C795 comes from CBloomFilter::Hash()
 
-    T(0x00000000, 0x00000000, "");
-    T(0x6a396f08, 0xFBA4C795, "");
-    T(0x81f16f39, 0xffffffff, "");
+    T(0x00000000U, 0x00000000, "");
+    T(0x6a396f08U, 0xFBA4C795, "");
+    T(0x81f16f39U, 0xffffffff, "");
 
-    T(0x514e28b7, 0x00000000, "00");
-    T(0xea3f0b17, 0xFBA4C795, "00");
-    T(0xfd6cf10d, 0x00000000, "ff");
+    T(0x514e28b7U, 0x00000000, "00");
+    T(0xea3f0b17U, 0xFBA4C795, "00");
+    T(0xfd6cf10dU, 0x00000000, "ff");
 
-    T(0x16c6b7ab, 0x00000000, "0011");
-    T(0x8eb51c3d, 0x00000000, "001122");
-    T(0xb4471bf8, 0x00000000, "00112233");
-    T(0xe2301fa8, 0x00000000, "0011223344");
-    T(0xfc2e4a15, 0x00000000, "001122334455");
-    T(0xb074502c, 0x00000000, "00112233445566");
-    T(0x8034d2a0, 0x00000000, "0011223344556677");
-    T(0xb4698def, 0x00000000, "001122334455667788");
+    T(0x16c6b7abU, 0x00000000, "0011");
+    T(0x8eb51c3dU, 0x00000000, "001122");
+    T(0xb4471bf8U, 0x00000000, "00112233");
+    T(0xe2301fa8U, 0x00000000, "0011223344");
+    T(0xfc2e4a15U, 0x00000000, "001122334455");
+    T(0xb074502cU, 0x00000000, "00112233445566");
+    T(0x8034d2a0U, 0x00000000, "0011223344556677");
+    T(0xb4698defU, 0x00000000, "001122334455667788");
 
 #undef T
 }
