@@ -13,6 +13,9 @@ class SignMessagesTest(BitcoinTestFramework):
         self.num_nodes = 1
         self.extra_args = [["-addresstype=legacy"]]
 
+    def skip_test_if_missing_module(self):
+        self.skip_if_no_wallet()
+
     def run_test(self):
         message = 'This is just a test message'
 
