@@ -17,6 +17,9 @@ class DisablePrivateKeysTest(BitcoinTestFramework):
         self.num_nodes = 1
         self.supports_cli = True
 
+    def skip_test_if_missing_module(self):
+        self.skip_if_no_wallet()
+
     def run_test(self):
         node = self.nodes[0]
         self.log.info("Test disableprivatekeys creation.")
