@@ -12,6 +12,9 @@ class ListSinceBlockTest (BitcoinTestFramework):
         self.num_nodes = 4
         self.setup_clean_chain = True
 
+    def skip_test_if_missing_module(self):
+        self.skip_if_no_wallet()
+
     def run_test(self):
         self.nodes[2].generate(101)
         self.sync_all()
